aboutsummaryrefslogtreecommitdiffstats
path: root/Software/Visual_Studio/Tango.Integration/Operators/IMachineOperator.cs
diff options
context:
space:
mode:
authorRoy Ben-Shabat <Roy@Twine-s.com>2018-02-13 16:35:28 +0200
committerRoy Ben-Shabat <Roy@Twine-s.com>2018-02-13 16:35:28 +0200
commitd5a5fd2813a98d97e0198342bbcc53df454c3e01 (patch)
tree8e3012262ba6417c3236d33a582df2d7ab0cd16a /Software/Visual_Studio/Tango.Integration/Operators/IMachineOperator.cs
parent2b1e86aeee219b236ba8cb33c5ebfa8bde89f14f (diff)
downloadTango-d5a5fd2813a98d97e0198342bbcc53df454c3e01.tar.gz
Tango-d5a5fd2813a98d97e0198342bbcc53df454c3e01.zip
Digital out.
Diffstat (limited to 'Software/Visual_Studio/Tango.Integration/Operators/IMachineOperator.cs')
-rw-r--r--Software/Visual_Studio/Tango.Integration/Operators/IMachineOperator.cs4
1 files changed, 2 insertions, 2 deletions
diff --git a/Software/Visual_Studio/Tango.Integration/Operators/IMachineOperator.cs b/Software/Visual_Studio/Tango.Integration/Operators/IMachineOperator.cs
index 078375e4f..e067e7a98 100644
--- a/Software/Visual_Studio/Tango.Integration/Operators/IMachineOperator.cs
+++ b/Software/Visual_Studio/Tango.Integration/Operators/IMachineOperator.cs
@@ -95,11 +95,11 @@ namespace Tango.Integration.Operators
Task<TangoMessage<DispenserAbortHomingResponse>> StopDispenserHoming(DispenserAbortHomingRequest request);
/// <summary>
/// Turn on/off the specified GPIO port.
/// </summary>
/// <param name="request">The request.</param>
/// <returns></returns>
- Task<TangoMessage<SetGPIOStateResponse>> SetGPIOState(SetGPIOStateRequest request);
+ Task<TangoMessage<SetDigitalOutResponse>> SetDigitalOut(SetDigitalOutRequest request);
/// <summary>
/// Starts jogging the thread motion system.
@@ -95,11 +95,11 @@ namespace Tango.Integration.Operators
Task<TangoMessage<DispenserAbortHomingResponse>> StopDispenserHoming(DispenserAbortHomingRequest request);
/// <summary>
- /// Turn on/off the specified GPIO port.
+ /// Turn on/off the specified digital output pin.
/// </summary>
/// <param name="request">The request.</param>